@@ -12,7 +12,8 @@ class TestClassify(unittest.TestCase):
         self.assertEqual(classify.classify(Optional[str]), Optional)
         self.assertEqual(classify.classify(Union[str, bool]), Union)
         self.assertEqual(classify.classify(Any), Any)
+
         @dataclass
         class X:
             pass
-        self.assertEqual(classify.classify(X), dataclass)
+        self.assertEqual(classify.classify(X), classify.IsDataclass)
